/*-
 * Copyright (c) 2001 Lev Walkin <vlm@spelio.net.ru>.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
 * OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
 * HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
 * LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * $Id: ips.c,v 1.10 2002/12/18 00:57:42 vlm Exp $
 */

#include "ipcad.h"
#include "opt.h"

packet_source_t *
create_packet_source(char *ifname, int iflags, char *filter) {
	packet_source_t *ps;

	ps = calloc(1, sizeof *ps);
	if(ps == NULL)
		return NULL;

#ifdef	PSRC_bpf
	ps->bpf_fd = -1;
#else	/* PSRC_bpf */
	ps->pcap_dev = NULL;
	if(pthread_mutex_init(&ps->pcap_dev_mutex, NULL) == -1) {
		free(ps);
		return NULL;
	}
#endif	/* PSRC_bpf */

	strncpy( ps->ifname, ifname, sizeof(ps->ifname) );
	ps->ifname[sizeof(ps->ifname) - 1] = 0;
	ps->iflags = iflags;
	ps->custom_filter = filter;

	ps->avg_period = 300;   /* 5 minutes */
	ps->bytes_lp = -1;	/* Initial value */
	ps->packets_lp = -1;	/* Initial value */

	ps->state = PST_EMBRYONIC;

	return ps;
}

